/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// RCS-ID:	$Id: PropertyListCtrl.cpp,v 1.4 2007/02/19 17:29:37 carl Exp $	
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include <wx/imaglist.h>

#include "PropertyListCtrl.h"

IMPLEMENT_DYNAMIC_CLASS(PropertyListCtrl, wxTreeListCtrl)

BEGIN_EVENT_TABLE(PropertyListCtrl, wxTreeListCtrl)
  EVT_SIZE (PropertyListCtrl::OnSize)
END_EVENT_TABLE()

// --------------------------------------------------------------------

PropertyListCtrl::PropertyListCtrl (wxWindow *parent, wxWindowID id,
				    const wxPoint &pos,
				    const wxSize &size) :
  wxTreeListCtrl (parent, id, pos, size,
		  wxTR_HIDE_ROOT | wxTR_HAS_BUTTONS |
		  wxTR_NO_LINES | wxTR_ROW_LINES)
{
  m_panel = wxDynamicCast (parent, wxPanel);
  wxASSERT (m_panel);

  // Establish columns.
  AddColumn ("Name");
  AddColumn ("Value");
  SetColumnWidth (1, 100);
}
//----------------------------------------------------------------------------

void PropertyListCtrl::update (RescueExplorerPairs &pairs)
{
  DeleteRoot ();

  // Create root.
  wxTreeItemId rootId = AddRoot ("root");

  for (size_t i=0; i<pairs.getCount(); i++) {
    wxTreeItemId id = AppendItem (rootId, pairs.getName (i));

    // Add value.
    SetItemText (id, 1, pairs.getValue (i));

    if (pairs.hasChildren (i)) {
      wxArrayString children = pairs.getChildren (i);
      for (size_t j=0; j < children.GetCount(); j++) {
	// Use index as name.
	wxTreeItemId childId = AppendItem (id, wxString::Format ("%d", j));
	// Add value.
	SetItemText (childId, 1, children[j]);
      }
    }
  }
}
//---------------------------------------------------------------------------
// Resize file name column as window resizes.

void PropertyListCtrl::OnSize (wxSizeEvent &event)
{
  int width = GetClientSize().GetWidth() / 2;
  SetColumnWidth (0, width);
  SetColumnWidth (1, width);

  event.Skip();
}
