// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerPairs.h"

#include "RCHString.h"

using namespace std;

//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, const wxString &value)
{
  m_names.Add (name);
  m_values.Add (value);
  m_children.push_back (wxArrayString ());
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name,
			       const wxString &summaryLabel,
			       const wxArrayString &values)
{
  m_names.Add (name);
  m_values.Add (summaryLabel);
  m_children.push_back (wxArrayString (values));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, RCHString *value)
{
  add (name, wxString::Format ("%s", value ? value->String() : "(null)"));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, const char *value)
{
  add (name, wxString::Format ("%s", value ? value : "(null)"));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, bool value)
{
  add (name, wxString (value ? "true" : "false"));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, int value)
{
  add (name, wxString::Format ("%d", value));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, unsigned char *values,
			       int count)
{
  m_names.Add (name);
  m_values.Add ("<unsigned char array>");

  wxArrayString children;
  for (int i=0; i<count; i++)
    children.Add (wxString::Format ("%d", values[i]));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, long value)
{
  add (name, wxString::Format ("%ld", value));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, long *values, long count)
{
  m_names.Add (name);
  m_values.Add ("<long int array>");

  wxArrayString children;
  for (long i=0; i<count; i++)
    children.Add (wxString::Format ("%ld", values[i]));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, long long value)
{
  add (name, wxString::Format ("%lld", value));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, unsigned short *values,
			       int count)
{
  m_names.Add (name);
  m_values.Add ("<short array>");

  wxArrayString children;
  for (int i=0; i<count; i++)
    children.Add (wxString::Format ("%d", values[i]));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, int *values, int count)
{
  m_names.Add (name);
  m_values.Add ("<int array>");

  wxArrayString children;
  for (int i=0; i<count; i++)
    children.Add (wxString::Format ("%d", values[i]));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, double value)
{
  add (name, wxString::Format ("%f", value));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, double *values, int count)
{
  m_names.Add (name);
  m_values.Add ("<double array>");

  wxArrayString children;
  for (int i=0; i<count; i++)
    children.Add (wxString::Format ("%f", values[i]));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, float value)
{
  add (name, wxString::Format ("%g", value));
}
//----------------------------------------------------------------------------

void RescueExplorerPairs::add (const wxString &name, float *values,
			       int count, double offset)
{
  m_names.Add (name);
  m_values.Add ("<float array>");

  wxArrayString children;
  for (int i=0; i<count; i++)
    children.Add (wxString::Format ("%g", values[i] + offset));
  m_children.push_back (children);
}
//----------------------------------------------------------------------------

size_t RescueExplorerPairs::getCount () const
{
  return m_names.GetCount();
}
//----------------------------------------------------------------------------

wxString RescueExplorerPairs::getName (size_t ix) const
{
  return m_names[ix];
}
//----------------------------------------------------------------------------

wxString RescueExplorerPairs::getValue (size_t ix) const
{
  return m_values[ix];
}
//----------------------------------------------------------------------------

bool RescueExplorerPairs::hasChildren (size_t ix) const
{
  return !m_children[ix].IsEmpty();
}
//----------------------------------------------------------------------------

wxArrayString RescueExplorerPairs::getChildren (size_t ix) const
{
  return m_children[ix];
}
