/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// RCS-ID:	$Id: array.cpp,v 1.5 2007/02/19 17:29:37 carl Exp $	
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

#include "RescueArrayDouble.h"
#include "RescueArrayFloat.h"
#include "RescueArrayByte.h"
#include "RescueArrayShort.h"
#include "RescueArrayInt.h"
#include "RescueArray2dVector.h"
#include "RescueArray3dVector.h"
#include "RescueVertex.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArrayDouble *array)
{
  wxTreeItemId leaf = addItem (parent, "ArrayDouble", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArrayFloat *array)
{
  wxTreeItemId leaf = addItem (parent, "ArrayFloat", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArrayByte *array)
{
  wxTreeItemId leaf = addItem (parent, "ArrayByte", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArrayShort *array)
{
  wxTreeItemId leaf = addItem (parent, "ArrayShort", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArrayInt *array)
{
  wxTreeItemId leaf = addItem (parent, "ArrayInt", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArray2dVector *array)
{
  wxTreeItemId leaf = addItem (parent, "Array2dVector", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueArray3dVector *array)
{
  wxTreeItemId leaf = addItem (parent, "Array3dVector", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueTripletArray *array)
{
  wxTreeItemId leaf = addItem (parent, "TripletArray", wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueQuadrupletArray *array)
{
  wxTreeItemId leaf = addItem (parent, "QuadrupletArray",
			       wxEmptyString, array);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArrayDouble *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue", array->NullValue());
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("Value", array->Value(), array->ValueLength());
  pairs.add ("MinValue", array->MinValue());
  pairs.add ("MaxValue", array->MaxValue());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArrayFloat *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue", array->NullValue());
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("Value", array->Value(), array->ValueLength());
  pairs.add ("MinValue", array->MinValue());
  pairs.add ("MaxValue", array->MaxValue());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArrayByte *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue", array->NullValue());
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("Value", array->Value(), array->ValueLength());
  pairs.add ("MinValue", array->MinValue());
  pairs.add ("MaxValue", array->MaxValue());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArrayShort *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue", array->NullValue());
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("Value", array->Value(), array->ValueLength());
  pairs.add ("MinValue", array->MinValue());
  pairs.add ("MaxValue", array->MaxValue());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArrayInt *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue", array->NullValue());
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("Value", array->Value(), array->ValueLength());
  pairs.add ("MinValue", array->MinValue());
  pairs.add ("MaxValue", array->MaxValue());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArray2dVector *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue",
	     wxString::Format ("%g,%g",
			       array->NullValue().coord1,
			       array->NullValue().coord2));
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("MinValue",
	     wxString::Format ("%g,%g",
			       array->MinValue().coord1,
			       array->MinValue().coord2));
  pairs.add ("MaxValue",
	     wxString::Format ("%g,%g",
			       array->MaxValue().coord1,
			       array->MaxValue().coord2));
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueArray3dVector *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("NullValue",
	     wxString::Format ("%g,%g,%g",
			       array->NullValue().coord1,
			       array->NullValue().coord2,
			       array->NullValue().coord3));
  pairs.add ("ValueLength", array->ValueLength());
  pairs.add ("MinValue",
	     wxString::Format ("%g,%g,%g",
			       array->MinValue().coord1,
			       array->MinValue().coord2,
			       array->MinValue().coord3));
  pairs.add ("MaxValue",
	     wxString::Format ("%g,%g,%g",
			       array->MaxValue().coord1,
			       array->MaxValue().coord2,
			       array->MaxValue().coord3));
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addProperties (RescueExplorerPairs &pairs,
					RescueArray *array)
{
  pairs.add ("PropertyName", array->PropertyName());
  pairs.add ("PropertyType", array->PropertyType());
  pairs.add ("UnitOfMeasure", array->UnitOfMeasure());
  pairs.add ("CellCentered", array->CellCentered() != 0);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueQuadrupletArray *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  pairs.add ("MDValueLength", array->MDValueLength());
  pairs.add ("MDValue", array->MDValue(), array->MDValueLength());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueTripletArray *array)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, array);
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addProperties (RescueExplorerPairs &pairs,
					RescueTripletArray *array)
{
  pairs.add ("MissingValue", array->MissingValue ());

  double xv, yv, zv;
  if (m_addVertex &&
      array->ParentModel() &&
      array->ParentModel()->CoordinateSystem() &&
      array->ParentModel()->CoordinateSystem()->Vertex()) {
    xv = array->ParentModel()->CoordinateSystem()->Vertex()->X();
    yv = array->ParentModel()->CoordinateSystem()->Vertex()->Y();
    zv = array->ParentModel()->CoordinateSystem()->Vertex()->Z();
  }
  else
    xv = yv = zv = 0.0;

  pairs.add ("RescueGetXValueLength", array->RescueGetXValueLength());
  pairs.add ("RescueGetXValue", array->RescueGetXValue(),
	     array->RescueGetXValueLength(), xv);

  pairs.add ("RescueGetYValueLength", array->RescueGetYValueLength());
  pairs.add ("RescueGetYValue", array->RescueGetYValue(),
	     array->RescueGetYValueLength(), yv);

  pairs.add ("RescueGetZValueLength", array->RescueGetZValueLength());
  pairs.add ("RescueGetZValue", array->RescueGetZValue(),
	     array->RescueGetZValueLength(), zv);
}
