
#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueBlockUnit *blockUnit)
{
  wxTreeItemId leaf = addItem (parent, "BlockUnit", wxEmptyString, blockUnit);

  for (int i=0; i<blockUnit->GeometryCount(); i++)
    addLeaf (leaf, blockUnit->GridGeometry (0));

  for (int i=0; i<blockUnit->CountOfVolumes(); i++)
    addLeaf (leaf, blockUnit->NthMacroVolume (i));
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueBlockUnit *blockUnit)
{
  RescueExplorerPairs pairs;
  pairs.add ("(Unit->UnitName)", blockUnit->Unit()->UnitName());
  pairs.add ("(Block->BlockName)", blockUnit->Block()->BlockName());
  pairs.add ("PropertyCount", blockUnit->PropertyCount());
  pairs.add ("CountOfPropertyGroup", blockUnit->CountOfPropertyGroup());
  pairs.add ("CountOfVolumes", blockUnit->CountOfVolumes());
  pairs.add ("CountOfGeobodies", blockUnit->CountOfGeobodies());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueBlockUnitHorizonSurface *surface)
{
  wxTreeItemId leaf = addItem (parent, "BlockUnitHorizonSurface",
			       wxEmptyString, surface);

  for (int i=0; i<surface->PropertyCount(); i++)
    addLeaf (leaf, surface->NthRescueProperty (i));

  for (int i=0; i<surface->CountOfPropertyGroup(); i++)
    addLeaf (leaf, surface->NthPropertyGroup (i));

  for (int i=0; i<surface->IJSurfaceCount(); i++)
    addLeaf (leaf, surface->NthIJSurface (i)); 
}
//----------------------------------------------------------------------------

void
RescueExplorerTree::showProperties (RescueBlockUnitHorizonSurface *surface)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, dynamic_cast<RescueReferenceSurface *>(surface));
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueBlockUnitSide *side)
{
  wxTreeItemId leaf = addItem (parent, "BlockUnitSide", wxEmptyString, side);

  if (side->Section())
    addLeaf (leaf, side->Section());

  if (side->Edges())
    addLeaf (leaf, side->Edges());
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueBlockUnitSide *side)
{
  RescueExplorerPairs pairs;
  updateList (pairs);
}
