
#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueCoordinateSystem *coordinateSystem)
{
  wxTreeItemId leaf = addItem (parent, "CoordinateSystem",
			       coordinateSystem->Name(), coordinateSystem);

  if (coordinateSystem->Vertex())
    addLeaf (leaf, coordinateSystem->Vertex());

  for (int i=0; i< coordinateSystem->Dimensions(); i++)
    addLeaf (leaf, coordinateSystem->Axis(i));
}
//----------------------------------------------------------------------------

const char *
RescueExplorerTree::orientationName (RescueCoordinateSystem::Orientation o)
{
  switch (o) {
  case RescueCoordinateSystem::LUF:
    return "LUF";
  case RescueCoordinateSystem::LUB:
    return "LUB";
  case RescueCoordinateSystem::LDF:
    return "LDF";
  case RescueCoordinateSystem::LDB:
    return "LDB";
  case RescueCoordinateSystem::RUF:
    return "RUF";
  case RescueCoordinateSystem::RUB:
    return "RUB";
  case RescueCoordinateSystem::RDF:
    return "RDF";
  case RescueCoordinateSystem::RDB:
    return "RDB";
  default:
    return "Unknown";
  }
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueCoordinateSystem *coordSystem)
{
  RescueExplorerPairs pairs;

  pairs.add ("Name", coordSystem->Name());

  pairs.add ("Orientation", orientationName (coordSystem->OrientationIs()));

  pairs.add ("InSys", coordSystem->InSys());
  pairs.add ("InZone", coordSystem->InZone());
  pairs.add ("InUnit", coordSystem->InUnit());
  pairs.add ("InSpheroid", coordSystem->InSpheroid());

  pairs.add ("SemiMajorAxis", coordSystem->SemiMajorAxis());
  pairs.add ("EccentricityOrSemiMinorAxis",
	     coordSystem->EccentricityOrSemiMinorAxis());
  pairs.add ("StandardLat", coordSystem->StandardLat());
  pairs.add ("SecondLat", coordSystem->SecondLat());
  pairs.add ("CentralLong", coordSystem->CentralLong());
  pairs.add ("LatOrigin", coordSystem->LatOrigin());
  pairs.add ("FalseEasting", coordSystem->FalseEasting());
  pairs.add ("FalseNorthing", coordSystem->FalseNorthing());

  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueCoordinateSystemAxis *axis)
{
  wxTreeItemId leaf = addItem (parent, "CoordinateSystemAxis",
			       axis->AxisName(), axis);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueCoordinateSystemAxis *axis)
{
  RescueExplorerPairs pairs;
  pairs.add ("Name", axis->AxisName());
  pairs.add ("UnitOfMeasure", axis->UnitOfMeasure());

  updateList (pairs);
}
