
#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

#include "RescueRadialGrid.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueGrid *grid)
{
  wxTreeItemId leaf = addItem (parent, "Grid", wxEmptyString, grid);

  for (int i=0; i<grid->Dimensions(); i++)
    addLeaf (leaf, grid->Axis(i));
}
//----------------------------------------------------------------------------

static wxString getAxisIndexLabel (RescueGridAxis::GridNdx axisIndex)
{
  wxString label;
  switch (axisIndex) {
  case RescueGridAxis::I_AXIS:
    return "I_AXIS";

  case RescueGridAxis::J_AXIS:
    return "J_AXIS";

  case RescueGridAxis::K_AXIS:
    return "K_AXIS";

  case RescueGridAxis::UNKNOWN:
  default:
    return "UNKNOWN";
  }
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueGrid *grid)
{
  RescueExplorerPairs pairs;
  pairs.add ("Dimensions", grid->Dimensions());
  pairs.add ("NodeCount (true)", grid->NodeCount (true));
  pairs.add ("NodeCount (false)", grid->NodeCount (false));
  pairs.add ("Vertices", grid->Vertices());
  pairs.add ("Orientation", orientationName (grid->DisplayOrientation()));

  for (int i=0; i<grid->Dimensions(); i++)
    pairs.add (wxString::Format ("IsRegular (%d)", i),
	       grid->IsRegular (i));

  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueGridAxis *axis)
{
  wxTreeItemId leaf = addItem (parent, "GridAxis",
			       getAxisIndexLabel (axis->AxisIndex()), axis);
  
  if (axis->RelatedCoordinateSystemAxis())
    addLeaf (leaf, axis->RelatedCoordinateSystemAxis());
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueGridAxis *axis)
{
  RescueExplorerPairs pairs;
  pairs.add ("AxisIndex", getAxisIndexLabel (axis->AxisIndex()));
  pairs.add ("LowBound", axis->LowBound());
  pairs.add ("Count", axis->Count ());
  pairs.add ("IsRegular", axis->IsRegular ());
  pairs.add ("Origin", axis->Origin());
  pairs.add ("Step", axis->Step());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueRadialGrid *grid)
{
#if 0	// Since RescueRadialGrid does not subclass from RescueObject.
  wxTreeItemId leaf = addItem (parent, "RadialGrid", wxEmptyString, grid);
#else
  wxString type ("RadialGrid");

  wxTreeItemId leaf =
    AppendItem (parent, type, -1, -1,
		new RescueExplorerTreeItemData (type, wxEmptyString, grid));
#endif
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueRadialGrid *grid)
{
  RescueExplorerPairs pairs;
  pairs.add ("MaxI", grid->MaxI());
  pairs.add ("MaxJ", grid->MaxJ());
  pairs.add ("MaxK", grid->MaxK());
  pairs.add ("Nodes", grid->Nodes());
  pairs.add ("VertexXLength", grid->VertexXLength());
  pairs.add ("VertexX", grid->VertexX(), grid->VertexXLength());
  pairs.add ("VertexYLength", grid->VertexYLength());
  pairs.add ("VertexY", grid->VertexY(), grid->VertexYLength());
  pairs.add ("VertexZLength", grid->VertexZLength());
  pairs.add ("VertexZ", grid->VertexZ(), grid->VertexZLength());
  updateList (pairs);
}
