/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// RCS-ID:	$Id: ijSurface.cpp,v 1.4 2007/08/21 10:16:10 carl Exp $	
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueIJSurface *surface)
{
  wxTreeItemId leaf = addItem (parent, "IJSurface", wxEmptyString, surface);

  if (surface->Grid())
    addLeaf (leaf, surface->Grid());

  if (surface->Geometry ())
    addLeaf (leaf, surface->Geometry());

  // Loop over the geometry/ies making sure the grid geometry
  // is loaded before checking for stair-stepped faults which
  // do not seem to load otherwise.
  for (int i=0; i< surface->ParentModel()->GeometryCount(); i++)
    surface->ParentModel()->GridGeometry (i)->EnsureLoaded();

  for (long long i=0; i<surface->StairSteppedFaultCount(); i++)
    addLeaf (leaf, surface->NthStairSteppedFault (i));
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueIJSurface *surface)
{
  RescueExplorerPairs pairs;
  pairs.add ("SurfaceCellCount", surface->SurfaceCellCount());
  pairs.add ("SurfaceGridCount", surface->SurfaceGridCount());
  pairs.add ("StairSteppedFaultCount", surface->StairSteppedFaultCount());
  updateList (pairs);
}
