/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// RCS-ID:	$Id: lookup.cpp,v 1.3 2007/02/19 17:29:37 carl Exp $	
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

#include "RescueLookup.h"
#include "RescueLookupString.h"
#include "RescueLookupTable.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueLookup *lookup)
{
  wxTreeItemId leaf = addItem (parent, "Lookup",
			       lookup->LookupName(), lookup);

  for (int i=0; i<lookup->Count(); i++) {
    RescueLookupItem *item = lookup->NthItem (i);
    if (!item)
      continue;
    if (item->IsA() == R_RescueLookupString)
      addLeaf (leaf, dynamic_cast<RescueLookupString *>(item));
    else if (item->IsA() == R_RescueLookupTable)
      addLeaf (leaf, dynamic_cast<RescueLookupTable *>(item));
  }    
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueLookupString *item)
{
  wxTreeItemId leaf = addItem (parent, "LookupString",
			       wxEmptyString, item);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueLookupTable *item)
{
  wxTreeItemId leaf = addItem (parent, "LookupTable",
			       wxEmptyString, item);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueLookup *lookup)
{
  RescueExplorerPairs pairs;
  pairs.add ("LookupName", lookup->LookupName());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueLookupString *item)
{
  RescueExplorerPairs pairs;
  pairs.add ("Translation", item->Translation());
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueLookupTable *item)
{
  RescueExplorerPairs pairs;
  pairs.add ("TranslationLength", item->TranslationLength());
  pairs.add ("Rows", item->Rows());
  updateList (pairs);
}
