/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueModel *model)
{
  wxTreeItemId leaf = addItem (parent, "Model", model->ModelName(), model);

  if (model->CoordinateSystem ())
    addLeaf (leaf, model->CoordinateSystem());

  for (int i=0; i< model->UnitCount(); i++)
    addLeaf (leaf, model->NthRescueUnit (i));

  for (int i=0; i< model->BlockCount(); i++)
    addLeaf (leaf, model->NthRescueBlock (i));

  for (int i=0; i< model->HorizonCount(); i++)
    addLeaf (leaf, model->NthRescueHorizon (i));

  for (int i=0; i< model->WellboreCount(); i++)
    addLeaf (leaf, model->NthRescueWellbore (i));

  for (int i=0; i< model->SectionCount(); i++)
    addLeaf (leaf, model->NthRescueSection (i));

  for (int i=0; i< model->GeometryCount(); i++)
    addLeaf (leaf, model->GridGeometry (i));

  for (int i=0; i< model->PropertyGroupCount(); i++)
    addLeaf (leaf, model->NthRescueModelPropertyGroup (i));

  for (int i=0; i< model->RescuePropertyGroupCount(); i++)
    addLeaf (leaf, model->NthRescuePropertyGroup (i));

  for (int i=0; i< model->HistoryCount(); i++)
    addLeaf (leaf, model->NthRescueHistory (i));

  for (int i=0; i< model->GeobodyCount(); i++)
    addLeaf (leaf, model->NthRescueGeobody (i));

  for (int i=0; i< model->ReferenceSurfaceCount(); i++)
    addLeaf (leaf, model->NthRescueReferenceSurface (i));

  for (int i=0; i< model->LookupCount(); i++)
    addLeaf (leaf, model->NthRescueLookup (i));

  for (int i=0; i< model->EventDescrCount(); i++)
    addLeaf (leaf, model->NthRescueEventDescr (i));

  for (int i=0; i< model->FaultIntersectionCount(); i++)
    addLeaf (leaf, model->NthRescueFaultIntersection (i));

  for (int i=0; i< model->ReservoirCount(); i++)
    addLeaf (leaf, model->NthRescueReservoir (i));

  for (int i=0; i< model->WireframeCount(); i++)
    addLeaf (leaf, model->NthRescueWireframe (i));

  if (model->Documents()) 
    addLeaf (leaf, model->Documents());

  Expand (leaf);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueModel *model)
{
  RescueExplorerPairs pairs;
  pairs.add ("ModelName", model->ModelName());
  pairs.add ("VendorName", model->VendorName());
  pairs.add ("VendorVersion", model->VendorVersion());
  pairs.add ("ModelDate", model->ModelDate());
  pairs.add ("UserName", model->UserName());
  pairs.add ("Rotation", model->Rotation());
  pairs.add ("IJKPreference", model->IJKPreference());

  updateList (pairs);
}
