/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

#include "RescueArrayDouble.h"
#include "RescueArrayFloat.h"
#include "RescueArrayByte.h"
#include "RescueArrayShort.h"
#include "RescueArrayInt.h"
#include "RescueArray2dVector.h"
#include "RescueArray3dVector.h"
#include "RescueProperty.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueProperty *property)
{
  RescueArray *data = property->Data();

  wxTreeItemId leaf = addItem (parent, "Property",
			       data ? data->PropertyName()->String() :
			       "(no data)",
			       property);
  if (data)
    switch (data->IsA()) {
    case R_RescueArrayDouble:
      addLeaf (leaf, dynamic_cast<RescueArrayDouble *>(data));
      break;
    case R_RescueArrayFloat:
      addLeaf (leaf, dynamic_cast<RescueArrayFloat *>(data));
      break;
    case R_RescueArrayByte:
      addLeaf (leaf, dynamic_cast<RescueArrayByte *>(data));
      break;
    case R_RescueArrayShort:
      addLeaf (leaf, dynamic_cast<RescueArrayShort *>(data));
      break;
    case R_RescueArrayInt:
      addLeaf (leaf, dynamic_cast<RescueArrayInt *>(data));
      break;
    case R_RescueArray2dVector:
      addLeaf (leaf, dynamic_cast<RescueArray2dVector *>(data));
      break;
    case R_RescueArray3dVector:
      addLeaf (leaf, dynamic_cast<RescueArray3dVector *>(data));
      break;
    }
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueProperty *property)
{
  RescueExplorerPairs pairs;

  if (property->ParentBlockUnit())
    pairs.add ("(ParentBlockUnit->BlockName)",
	       property->ParentBlockUnit()->Block()->BlockName());
  else
    pairs.add ("(ParentBlockUnit)", 0);

  pairs.add ("TriangulatedSurface", property->TriangulatedSurface() == TRUE);
  updateList (pairs);
}
