/////////////////////////////////////////////////////////////////////////////
// Name:        RESCUE Explorer
// Purpose:     Explore RESCUE exports
// Copyright:   (C) 2006, Carl Godkin (carl@dgi.com)
// RCS-ID:	$Id: surface.cpp,v 1.3 2007/02/19 17:29:38 carl Exp $	
// License:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

#include "RescueExplorerTree.h"

//----------------------------------------------------------------------------

void RescueExplorerTree::addLeaf (const wxTreeItemId &parent,
				  RescueSurface *surface)
{
  wxTreeItemId leaf = addItem (parent, "Surface", wxEmptyString, surface);

  for (int i=0; i<surface->PropertyCount(); i++)
    addLeaf (leaf, surface->NthRescueProperty (i));

  for (int i=0; i<surface->CountOfPropertyGroup(); i++)
    addLeaf (leaf, surface->NthPropertyGroup (i));

  for (int i=0; i<surface->IJSurfaceCount(); i++)
    addLeaf (leaf, surface->NthIJSurface (i)); 
}
//----------------------------------------------------------------------------

static const char *getSurfaceTypeLabel (RescueSurface::SurfaceType type)
{
  switch (type) {
  case RescueSurface::AUXILLIARY:
    return "AUXILLIARY";
  case RescueSurface::FAULT:
    return "FAULT";
  case RescueSurface::UNCONFORMITY:
    return "UNCONFORMITY";
  case RescueSurface::LEASE_BOUNDARY:
    return "BOUNDARY";
  case RescueSurface::HORIZON:
    return "HORIZON";
  case RescueSurface::OIL_CONTACT:
    return "CONTACT";
  case RescueSurface::GAS_CONTACT:
    return "CONTACT";
  case RescueSurface::WATER_CONTACT:
    return "CONTACT";
  case RescueSurface::SALT_DOME:
    return "DOME";
  default:
    return "unknown";
  }
}
//----------------------------------------------------------------------------

void RescueExplorerTree::showProperties (RescueSurface *surface)
{
  RescueExplorerPairs pairs;
  addProperties (pairs, surface);
  updateList (pairs);
}
//----------------------------------------------------------------------------

void RescueExplorerTree::addProperties (RescueExplorerPairs &pairs,
					RescueSurface *surface)
{
  pairs.add ("SurfaceType", getSurfaceTypeLabel (surface->Type()));
}
